<h1>一、深度学习的一些工具（基础阶段的，供参考学习使用）</h1>
<p>
这个包就是一些简单的深度学习的基础工具（刚开始学习的工具），就是为了方便学习使用，也是方便本人在非实验室环境下
也能使用，这些工具，而且这个包在不断完善中，之所以上传也是为了激励自己学习。
</p>
<h1>二、特性</h1>
<ol>
<h2>工具介绍：</h2>
<li>加载数据，这里使用的是MNIST图像数据：cyzgetimagdata</li>
<li>softmax工具：cyzsoftmax</li>
<li>损失函数（交叉熵损失）：cyzcrossfunction</li>
<li>优化算法SGD梯度下降工具：cyzsgd</li>
<li>计算分类准确率：cyzaccuracy</li>
<li>训练：cyztrain</li>
<li>作图的方法：cyzplt</li>
<li>定义Droput函数（丢弃法）：cyzdroupt</li>
</ol>
<h1>三、安装步骤</h1>
1.使用 yarn
如果你更喜欢使用 yarn，可以使用以下命令安装 cyzhub：

yarn add cyzhub

2.使用 pip

如果你的项目是 Python 项目，可以使用 pip 安装 cyzhub：

pip install cyzhub

<h1>四、安装后的检验</h1>
对于Python：
import cyzhub

print(cyzhub)  

应该输出 CyzHub 的相关信息

<h1>五、使用示例</h1>
参考test目录下的文件
<h1>六、贡献</h1>
欢迎任何形式的贡献！
<h1>七、许可证</h1>
该项目采用 MIT 许可证。
<h1>八、联系方式</h1>
如有问题，请联系：cyzroot@outlook.com
